@@ -31,26 +31,26 @@ class Controller(object):
         self.check_inp = args.skip_check
         self.keep_tmp = args.keep_tmp
         self.lvl = args.log_lvl
-        self.aa = args.aa
         self.redo = args.redo_typing
         self.kmer = args.kmer
         self.crispr_cas_dist = args.ccd
+        self.pred_prob = args.pred_prob
 
+        self.any_cas = False
+        self.any_operon = False
+        self.any_crispr = False
+            
         # Logger
         logging.basicConfig(format='\033[36m'+'[%(asctime)s] %(levelname)s:'+'\033[0m'+' %(message)s', datefmt='%Y-%m-%d %H:%M:%S', level=self.lvl)
-        logging.info('Running CasPredict version 0.3.0')
+        logging.info('Running CasPredict version 0.3.5')
 
         # Force consistency
         self.out = os.path.join(self.out, '')
 
         if self.redo:
-            self.aa = True
             self.check_inp = True
 
-        if self.aa:
-            self.prot_path = self.fasta
-        else:
-            self.prot_path = self.out+'proteins.faa'
+        self.prot_path = self.out+'proteins.faa'
 
         # Hardcode single gene types
         self.single_gene_types=('II-A','II-B','II-C','V-A','V-B','V-C','V-D','V-E','V-F','V-G','V-H','V-I','V-J','VI-A','VI-B','VI-C','VI-D')
@@ -62,6 +62,13 @@ class Controller(object):
         self.check_input()
         self.check_out()
 
+        # If redo check if any crisprs and operons
+        if self.redo:
+            if os.path.exists(self.out+'cas_operons.tab') or os.path.exists(self.out+'cas_operons_putative.tab'):
+                self.any_operon = True
+            if os.path.exists(self.out+'crisprs_all.tab'):
+                self.any_crispr = True
+
         # Write arguments
         da = vars(args)
         f = open(self.out+'arguments.tab', 'w')
@@ -106,10 +113,9 @@ class Controller(object):
                 
                 shutil.rmtree(self.out+'hmmer')
                 
-                if not self.aa:
-                    os.remove(self.out+'minced.out')
-                    os.remove(self.out+'prodigal.log')
-                    os.remove(self.out+'proteins.faa')
+                os.remove(self.out+'minced.out')
+                os.remove(self.out+'prodigal.log')
+                os.remove(self.out+'proteins.faa')
 
     def check_db(self):
         
